@@ -1,4 +1,4 @@
-/* Copyright (c) 1996, 1997, 1998, 1999, 2001 Thorsten Kukuk
+/* Copyright (c) 1996, 1997, 1998, 1999, 2001, 2002, 2003 Thorsten Kukuk
    Author: Thorsten Kukuk <kukuk@suse.de>
 
    The YP Server is free software; you can redistribute it and/or
@@ -45,15 +45,19 @@
 #include <rpc/svc_soc.h>
 #endif
 #include <rpc/pmap_clnt.h>
+#ifdef HAVE_GETOPT_H
 #include <getopt.h>
+#endif /* HAVE_GETOPT_H */
 #include "ypxfrd.h"
 #include "access.h"
+#include "ypserv_conf.h"
 
 #ifndef SA_RESTART
 #define SA_RESTART 0
 #endif
 
 #include "log_msg.h"
+#include "compat.h"
 
 extern void ypxfrd_freebsd_prog_1(struct svc_req *, SVCXPRT *);
 
@@ -72,40 +76,6 @@ char *path_ypdb = YPMAPDIR;
 
 char *progname;
 
-#if HAVE__RPC_DTABLESIZE
-extern int _rpc_dtablesize(void);
-#elif HAVE_GETDTABLESIZE
-static int
-_rpc_dtablesize()
-{
-  static int size;
-
-  if (size == 0)
-    {
-      size = getdtablesize();
-    }
-  return (size);
-}
-#else
-
-#include <sys/resource.h>
-
-static int
-_rpc_dtablesize()
-{
-  static int size = 0;
-  struct rlimit rlb;
-
-  if (size == 0)
-    {
-      if (getrlimit(RLIMIT_NOFILE, &rlb) >= 0)
-	size = rlb.rlim_cur;
-    }
-
-  return size;
-}
-#endif
-
 /*
 ** Needed, if we start rpc.ypxfrd from inetd
 */
@@ -134,7 +104,7 @@ closedown (int sig)
 
 /* Clean up after child processes signal their termination.  */
 static void
-sig_child (int sig __attribute__ ((unused)))
+sig_child (int sig UNUSED)
 {
    int st;
 
@@ -145,7 +115,7 @@ sig_child (int sig __attribute__ ((unused)))
 
 /* Clean up if we quit the program.  */
 static void
-sig_quit (int sig __attribute__ ((unused)))
+sig_quit (int sig UNUSED)
 {
   pmap_unset (YPXFRD_FREEBSD_PROG, YPXFRD_FREEBSD_VERS);
   exit (0);
@@ -155,10 +125,12 @@ sig_quit (int sig __attribute__ ((unused)))
 ** Reload securenets and config file
 */
 static void
-sig_hup (int sig __attribute__ ((unused)))
+sig_hup (int sig UNUSED)
 {
   load_securenets();
   load_config();
+  /* we don't wish to cache the file handles.  */
+  cached_filehandles = 0;
 }
 
 static void
@@ -179,7 +151,7 @@ main (int argc, char **argv)
   struct sockaddr_in socket_address;
   int result;
   struct sigaction sa;
-  int socket_size;
+  socklen_t socket_size;
 
   progname = strrchr (argv[0], '/');
   if (progname == (char *) NULL)
@@ -289,6 +261,8 @@ main (int argc, char **argv)
 
   load_securenets();
   load_config();
+  /* we don't wish to cache the file handles.  */
+  cached_filehandles = 0;
 
   /*
    * Ignore SIGPIPEs. They can hurt us if someone does a ypcat
@@ -352,7 +326,7 @@ main (int argc, char **argv)
   _rpcfdtype = 0;
   if (getsockname(0, (struct sockaddr *)&socket_address, &socket_size) == 0)
     {
-      int  int_size = sizeof (int);
+      socklen_t  int_size = sizeof (int);
       if (socket_address.sin_family != AF_INET)
 	return 1;
       if (getsockopt(0, SOL_SOCKET, SO_TYPE, (void*)&_rpcfdtype,
